@@ -30,7 +30,9 @@ import requests
 from flask import Flask, send_from_directory, make_response
 from werkzeug.exceptions import NotFound
 
+from dwave.inspector.config import config
 from dwave.inspector.storage import problem_store, problem_access_sem, get_problem, get_solver_data
+from dwave.inspector.utils import NumpyJSONProvider
 
 
 # get local server/app logger
@@ -165,6 +167,10 @@ class WSGIAsyncServer(threading.Thread):
         return 'http://{}:{}/api/callback/{}'.format(
             *self.server.server_address, problem_id)
 
+    def get_problem_url(self, problem_id):
+        return 'http://{}:{}/api/problems/{}'.format(
+            *self.server.server_address, problem_id)
+
     def _ensure_accessible(self, sleep=0.1, tries=100, timeout=10):
         """Ping the canary URL (app root) until the app becomes accessible."""
 
@@ -212,6 +218,7 @@ class WSGIAsyncServer(threading.Thread):
 
 
 app = Flask(__name__, static_folder=None)
+app.json = NumpyJSONProvider(app)
 
 @app.route('/')
 @app.route('/<path:path>')
@@ -255,4 +262,4 @@ def add_header(response):
         response.cache_control.max_age = 86400
     return response
 
-app_server = WSGIAsyncServer(host='127.0.0.1', base_port=18000, app=app)
+app_server = WSGIAsyncServer(host=config.host, base_port=config.base_port, app=app)
